@@ -1,5 +1,6 @@
 from __future__ import annotations
 
+from textwrap import dedent
 from copy import deepcopy
 from functools import partial
 from typing import Any, Callable, ClassVar, cast
@@ -79,7 +80,18 @@ class FieldsAggregationMetaClass(type):
     fields: Sequence[str]
 
     def __new__(cls, name: str, bases: tuple[type, ...], attrs: dict[str, Any]) -> type:
-        attrs["fields"] = set(attrs.get("fields", ()))
+        fields = attrs.get("fields", ())
+        if isinstance(fields, str):
+            raise ImproperlyConfigured(
+                dedent(f"""`fields` property should be list or tuple, received `str`.
+
+                Hint: Replace with:
+
+                    fields = ("{fields}", )
+                """)
+            )
+        else:
+            attrs["fields"] = set(fields)
         for base in bases:
             if isinstance(base, FieldsAggregationMetaClass):
                 attrs["fields"].update(base.fields)
@@ -112,7 +124,7 @@ class TranslationOptions(metaclass=FieldsAggregationMetaClass):
         mt_settings.REQUIRED_LANGUAGES
     )
 
-    def __init__(self, model: Model) -> None:
+    def __init__(self, model: type[Model]) -> None:
         """
         Create fields dicts without any translation fields.
         """
@@ -325,8 +337,8 @@ def patch_constraints(model: type[Model], opts: TranslationOptions) -> None:
         for constraint in model._meta.unique_together:
             for field_name in opts.fields:
                 if field_name in constraint:
-                    new_constraint = list(constraint)
                     for translated_name in get_translation_fields(field_name):
+                        new_constraint = list(constraint)
                         new_constraint[constraint.index(field_name)] = translated_name
                         yield new_constraint
 
